/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
import { BaseClient, ClientConfig, Response } from "@commerce-apps/core";
import { OperationOptions } from "retry";
import {
  FirewallRuleT,
  CollectionResponseEnvelopeT,
  WafGroupEnvelopeT,
  ZoneT,
  ZonesEnvelopeT,
  ItemResponseEnvelopeT,
  ZoneEnvelopeT,
  FirewallRuleEnvelopeT,
  FirewallRulesEnvelopeT,
  ErrorResponseT,
  WafGroupsEnvelopeT,
  WafRulesEnvelopeT,
  WafGroupT,
  WafRuleEnvelopeT,
  WafRuleT,
  MoneyT,
  SimpleSearchResultT,
  SearchRequestT,
  PaginatedSearchResultT,
  BoolFilterT,
  MatchAllQueryT,
  FilteredQueryT,
  QueryFilterT,
  QueryT,
  TermQueryT,
  TermFilterT,
  TextQueryT,
  Range2FilterT,
  BoolQueryT,
  NestedQueryT,
  FilterT,
  SortT,
  RangeFilterT
} from "./cdnZones.types";
/**
 * Instantiate a Client object with desired ClientConfig to perform operations
 * available in this API client.
 *
 * Note: When performing operations that require ShopperJWT authentication, an
 * Authorization header containing a JWT can be added to the headers field of the
 * ClientConfig object. The Client will use that Authorization header for all the
 * operations it is used to perform.
 */
declare class CdnZones extends BaseClient {
  constructor(config: ClientConfig);
  /**
   * Retrieves zone information.
   *
   * If you would like to get a raw Response object use the other getZonesInfo function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param offset -
   * @param limit - Maximum records to retrieve per request, not to exceed 50. Defaults to 25.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type ZonesEnvelopeT.
   */
  getZonesInfo(options?: {
    parameters?: {
      organizationId?: string;
      offset?: number;
      limit?: number;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<ZonesEnvelopeT>;
  /**
   * Retrieves zone information.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param offset -
   * @param limit - Maximum records to retrieve per request, not to exceed 50. Defaults to 25.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type ZonesEnvelopeT otherwise.
   */
  getZonesInfo<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        offset?: number;
        limit?: number;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ZonesEnvelopeT>;
  /**
   * Retrieves all WAF groups accessible to the caller.
   *
   * If you would like to get a raw Response object use the other getWafGroups function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type WafGroupsEnvelopeT.
   */
  getWafGroups(options?: {
    parameters?: {
      organizationId?: string;
      zoneId: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<WafGroupsEnvelopeT>;
  /**
   * Retrieves all WAF groups accessible to the caller.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type WafGroupsEnvelopeT otherwise.
   */
  getWafGroups<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        zoneId: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : WafGroupsEnvelopeT>;
  /**
   * Update action or mode of a specific WAF group.
   *
   * If you would like to get a raw Response object use the other updateWafGroup function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param groupId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type WafGroupEnvelopeT.
   */
  updateWafGroup(options: {
    parameters?: {
      organizationId?: string;
      zoneId: string;
      groupId: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: WafGroupT;
  }): Promise<WafGroupEnvelopeT>;
  /**
   * Update action or mode of a specific WAF group.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param groupId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type WafGroupEnvelopeT otherwise.
   */
  updateWafGroup<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        zoneId: string;
        groupId: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: WafGroupT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : WafGroupEnvelopeT>;
  /**
   * Retrieve WAF rules under the waf group specified by the caller.
   *
   * If you would like to get a raw Response object use the other getWafRules function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param groupId - WAF Group that contains the WAF rules.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type WafRulesEnvelopeT.
   */
  getWafRules(options?: {
    parameters?: {
      organizationId?: string;
      zoneId: string;
      groupId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<WafRulesEnvelopeT>;
  /**
   * Retrieve WAF rules under the waf group specified by the caller.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param groupId - WAF Group that contains the WAF rules.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type WafRulesEnvelopeT otherwise.
   */
  getWafRules<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        zoneId: string;
        groupId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : WafRulesEnvelopeT>;
  /**
   * Retrieve details of a specific WAF rule.
   *
   * If you would like to get a raw Response object use the other getWafRule function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param ruleId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type WafRuleEnvelopeT.
   */
  getWafRule(options?: {
    parameters?: {
      organizationId?: string;
      zoneId: string;
      ruleId: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<WafRuleEnvelopeT>;
  /**
   * Retrieve details of a specific WAF rule.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param ruleId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type WafRuleEnvelopeT otherwise.
   */
  getWafRule<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        zoneId: string;
        ruleId: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : WafRuleEnvelopeT>;
  /**
   * Update action of a specific WAF rule.
   *
   * If you would like to get a raw Response object use the other updateWafRule function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param ruleId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type WafRuleEnvelopeT.
   */
  updateWafRule(options: {
    parameters?: {
      organizationId?: string;
      zoneId: string;
      ruleId: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: WafRuleT;
  }): Promise<WafRuleEnvelopeT>;
  /**
   * Update action of a specific WAF rule.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param ruleId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type WafRuleEnvelopeT otherwise.
   */
  updateWafRule<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        zoneId: string;
        ruleId: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: WafRuleT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : WafRuleEnvelopeT>;
  /**
   * Retrieves existing firewall rules.
   *
   * If you would like to get a raw Response object use the other getFirewallRules function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type FirewallRulesEnvelopeT.
   */
  getFirewallRules(options?: {
    parameters?: {
      organizationId?: string;
      zoneId: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<FirewallRulesEnvelopeT>;
  /**
   * Retrieves existing firewall rules.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type FirewallRulesEnvelopeT otherwise.
   */
  getFirewallRules<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        zoneId: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : FirewallRulesEnvelopeT>;
  /**
   * Creates a firewall rule.
   *
   * If you would like to get a raw Response object use the other createFirewallRule function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type FirewallRuleEnvelopeT.
   */
  createFirewallRule(options: {
    parameters?: {
      organizationId?: string;
      zoneId: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: FirewallRuleT;
  }): Promise<FirewallRuleEnvelopeT>;
  /**
   * Creates a firewall rule.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type FirewallRuleEnvelopeT otherwise.
   */
  createFirewallRule<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        zoneId: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: FirewallRuleT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : FirewallRuleEnvelopeT>;
  /**
   * Retrieve a specific firewall rule.
   *
   * If you would like to get a raw Response object use the other getFirewallRule function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param firewallRuleId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type FirewallRuleEnvelopeT.
   */
  getFirewallRule(options?: {
    parameters?: {
      organizationId?: string;
      zoneId: string;
      firewallRuleId: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<FirewallRuleEnvelopeT>;
  /**
   * Retrieve a specific firewall rule.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param firewallRuleId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type FirewallRuleEnvelopeT otherwise.
   */
  getFirewallRule<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        zoneId: string;
        firewallRuleId: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : FirewallRuleEnvelopeT>;
  /**
   * Update a specific firewall rule.
   *
   * If you would like to get a raw Response object use the other updateFirewallRule function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param firewallRuleId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type FirewallRuleEnvelopeT.
   */
  updateFirewallRule(options: {
    parameters?: {
      organizationId?: string;
      zoneId: string;
      firewallRuleId: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: FirewallRuleT;
  }): Promise<FirewallRuleEnvelopeT>;
  /**
   * Update a specific firewall rule.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param firewallRuleId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type FirewallRuleEnvelopeT otherwise.
   */
  updateFirewallRule<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        zoneId: string;
        firewallRuleId: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: FirewallRuleT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : FirewallRuleEnvelopeT>;
  /**
   * Delete a specific firewall rule.
   *
   * If you would like to get a raw Response object use the other deleteFirewallRule function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param firewallRuleId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type void.
   */
  deleteFirewallRule(options?: {
    parameters?: {
      organizationId?: string;
      zoneId: string;
      firewallRuleId: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<void>;
  /**
   * Delete a specific firewall rule.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param firewallRuleId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
   */
  deleteFirewallRule<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        zoneId: string;
        firewallRuleId: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : void>;
}
declare namespace CdnZones {
  type FirewallRule = FirewallRuleT;
  type CollectionResponseEnvelope = CollectionResponseEnvelopeT;
  type WafGroupEnvelope = WafGroupEnvelopeT;
  type Zone = ZoneT;
  type ZonesEnvelope = ZonesEnvelopeT;
  type ItemResponseEnvelope = ItemResponseEnvelopeT;
  type ZoneEnvelope = ZoneEnvelopeT;
  type FirewallRuleEnvelope = FirewallRuleEnvelopeT;
  type FirewallRulesEnvelope = FirewallRulesEnvelopeT;
  type ErrorResponse = ErrorResponseT;
  type WafGroupsEnvelope = WafGroupsEnvelopeT;
  type WafRulesEnvelope = WafRulesEnvelopeT;
  type WafGroup = WafGroupT;
  type WafRuleEnvelope = WafRuleEnvelopeT;
  type WafRule = WafRuleT;
  type Money = MoneyT;
  type SimpleSearchResult = SimpleSearchResultT;
  type SearchRequest = SearchRequestT;
  type PaginatedSearchResult = PaginatedSearchResultT;
  type BoolFilter = BoolFilterT;
  type MatchAllQuery = MatchAllQueryT;
  type FilteredQuery = FilteredQueryT;
  type QueryFilter = QueryFilterT;
  type Query = QueryT;
  type TermQuery = TermQueryT;
  type TermFilter = TermFilterT;
  type TextQuery = TextQueryT;
  type Range2Filter = Range2FilterT;
  type BoolQuery = BoolQueryT;
  type NestedQuery = NestedQueryT;
  type Filter = FilterT;
  type Sort = SortT;
  type RangeFilter = RangeFilterT;
}
export = CdnZones;
