/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
import { BaseClient, ClientConfig, Response } from "@commerce-apps/core";
import { OperationOptions } from "retry";
import {
  StoreResultT,
  StoreT,
  MoneyT,
  SimpleSearchResultT,
  SearchRequestT,
  PaginatedSearchResultT,
  BoolFilterT,
  MatchAllQueryT,
  FilteredQueryT,
  QueryFilterT,
  QueryT,
  TermQueryT,
  TermFilterT,
  TextQueryT,
  Range2FilterT,
  BoolQueryT,
  NestedQueryT,
  FilterT,
  SortT,
  RangeFilterT,
  ErrorResponseT
} from "./shopperStores.types";
/**
 * Instantiate a Client object with desired ClientConfig to perform operations
 * available in this API client.
 *
 * Note: When performing operations that require ShopperJWT authentication, an
 * Authorization header containing a JWT can be added to the headers field of the
 * ClientConfig object. The Client will use that Authorization header for all the
 * operations it is used to perform.
 */
declare class ShopperStores extends BaseClient {
  constructor(config: ClientConfig);
  /**
   * This resource retrieves a list of stores for the given site that are within a configured distance of a geolocation. The distance is interpreted either in miles or kilometers, depending on the distanceUnit input parameter. The location is specified either by directly providing a latitude and longitude coordinate pair, or by providing a country and a postal code. If a postal code is passed, the resource looks in the system's geolocation mappings to find the coordinates for this postal code. If no matching geolocation is found, the resource returns an empty list of stores. If coordinates are passed, the values for country and postal code are ignored.
   *
   * If you would like to get a raw Response object use the other getStores function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param siteId -
   * @param latitude - The geographical latitude to search for stores (value range -90.00 .. 90.00).
   * @param longitude - The geographical longitude to search for stores (value range -180.00 .. 180.00).
   * @param countryCode - The two letter ISO country code, such as "US".
   * @param postalCode - The postal code, such as "84121".
   * @param distanceUnit - The distance unit. Supported values are "mi" (miles) and "km" (kilometers). The default is "km".
   * @param maxDistance - The area (radius) in distanceUnit where stores will be searched.
   * @param offset -
   * @param limit - Maximum records to retrieve per request, not to exceed 200. Defaults to 25.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type StoreResultT.
   */
  getStores(options?: {
    parameters?: {
      organizationId?: string;
      siteId?: string;
      latitude?: number;
      longitude?: number;
      countryCode?: string;
      postalCode?: string;
      distanceUnit?: string;
      maxDistance?: number;
      offset?: number;
      limit?: number;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<StoreResultT>;
  /**
   * This resource retrieves a list of stores for the given site that are within a configured distance of a geolocation. The distance is interpreted either in miles or kilometers, depending on the distanceUnit input parameter. The location is specified either by directly providing a latitude and longitude coordinate pair, or by providing a country and a postal code. If a postal code is passed, the resource looks in the system's geolocation mappings to find the coordinates for this postal code. If no matching geolocation is found, the resource returns an empty list of stores. If coordinates are passed, the values for country and postal code are ignored.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param siteId -
   * @param latitude - The geographical latitude to search for stores (value range -90.00 .. 90.00).
   * @param longitude - The geographical longitude to search for stores (value range -180.00 .. 180.00).
   * @param countryCode - The two letter ISO country code, such as "US".
   * @param postalCode - The postal code, such as "84121".
   * @param distanceUnit - The distance unit. Supported values are "mi" (miles) and "km" (kilometers). The default is "km".
   * @param maxDistance - The area (radius) in distanceUnit where stores will be searched.
   * @param offset -
   * @param limit - Maximum records to retrieve per request, not to exceed 200. Defaults to 25.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type StoreResultT otherwise.
   */
  getStores<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        siteId?: string;
        latitude?: number;
        longitude?: number;
        countryCode?: string;
        postalCode?: string;
        distanceUnit?: string;
        maxDistance?: number;
        offset?: number;
        limit?: number;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : StoreResultT>;
  /**
   * Returns a store identified by its ID.
   *
   * If you would like to get a raw Response object use the other getStore function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param id - The ID of the requested store.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type StoreT.
   */
  getStore(options?: {
    parameters?: {
      organizationId?: string;
      id: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<StoreT>;
  /**
   * Returns a store identified by its ID.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param id - The ID of the requested store.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type StoreT otherwise.
   */
  getStore<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        id: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : StoreT>;
}
declare namespace ShopperStores {
  type StoreResult = StoreResultT;
  type Store = StoreT;
  type Money = MoneyT;
  type SimpleSearchResult = SimpleSearchResultT;
  type SearchRequest = SearchRequestT;
  type PaginatedSearchResult = PaginatedSearchResultT;
  type BoolFilter = BoolFilterT;
  type MatchAllQuery = MatchAllQueryT;
  type FilteredQuery = FilteredQueryT;
  type QueryFilter = QueryFilterT;
  type Query = QueryT;
  type TermQuery = TermQueryT;
  type TermFilter = TermFilterT;
  type TextQuery = TextQueryT;
  type Range2Filter = Range2FilterT;
  type BoolQuery = BoolQueryT;
  type NestedQuery = NestedQueryT;
  type Filter = FilterT;
  type Sort = SortT;
  type RangeFilter = RangeFilterT;
  type ErrorResponse = ErrorResponseT;
}
export = ShopperStores;
